tests package — imagedata 1.4.3dev0 documentation

# tests package

## Submodules

## tests.compare_headers module

`tests.compare_headers.` `compare_geometry_headers`(self, hdr, newhdr)

`tests.compare_headers.` `compare_headers`(self, hdr, newhdr, uid=True)

`tests.compare_headers.` `compare_optional`(self, a, b, attr)

`tests.compare_headers.` `compare_template_headers`(self, hdr, newhdr, uid=True)

## tests.context module

## tests.test_archive_file module

## tests.test_archive_zip module

## tests.test_axis module

## tests.test_formats_dicom module

## tests.test_formats_dicom_color module

## tests.test_formats_dicom_template module

## tests.test_formats_dicom_zip module

## tests.test_formats_itk module

## tests.test_formats_itk_template module

## tests.test_formats_itk_zip module

## tests.test_formats_mat module

## tests.test_formats_mat_zip module

## tests.test_formats_nifti module

## tests.test_formats_nifti_zip module

## tests.test_formats_ps module

## tests.test_series module

## tests.test_transport_dicomtransport module

## tests.test_transport_filetransport module

## tests.test_version module

## Module contents